==> kadu_0.5.0.orig.tar.gz: kadu/modules/migration/translations/migration_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MigrationDialog</name>
    <message>
        <source>Migration</source>
        <translation>Migration</translation>
    </message>
    <message>
        <source>Migration steps</source>
        <translation>Migrationsschritte</translation>
    </message>
    <message>
        <source>Migration in progress ...</source>
        <translation>Migration läuft...</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Kadu detected, that you were using EKG, GnuGadu or
older version of Kadu before. Would you like to try
to import your settings from %1?</source>
        <translation>Kadu hat entdeckt, dass Sie EKG, GnuGadu oder
eine ältere Version von Kadu verwendet haben. Soll ich versuchen,
die Einstellungen von %1 zu importieren?</translation>
    </message>
    <message>
        <source>Step 1: Migrating settings to kadu directory</source>
        <translation>Schritt 1: Migration der Einstellungen in das Kadu-Verzeichnis</translation>
    </message>
    <message>
        <source>Step 1: Settings migrated to kadu directory</source>
        <translation>Schritt 1: Einstellungen wurden in das Kadu-Verzeichnis übernommen</translation>
    </message>
    <message>
        <source>Migration process completed. You can remove
%1directory
(backup will be a good idea) or leave it for other applications.</source>
        <translation>Migration beendet. Sie können das Verzeichnis
%1 löschen
(eine Sicherungskopie wäre nicht schlecht) 
bzw. zur weiteren Verwendung für andere Programme lassen.</translation>
    </message>
    <message>
        <source>Error migrating data!</source>
        <translation>Fehler bei der Übernahme der Einstellungen!</translation>
    </message>
    <message>
        <source>Cannot start migration process!</source>
        <translation>Kann den Migration nicht starten!</translation>
    </message>
    <message>
        <source>Step 2: Migrating user list to kadu.conf.xml</source>
        <translation>Schritt 2: MIgration der Kontaktliste in kadu.conf.xml</translation>
    </message>
    <message>
        <source>Step 2: User list migrated to kadu.conf.xml</source>
        <translation>Schritt 2: Kontaktliste ins kadu.conf.xml übernommen</translation>
    </message>
    <message>
        <source>Contact list migrated to kadu.conf.xml.You can remove
%1 and
%2 now
(backup will be a good idea).</source>
        <translation>Kontaktliste in kadu.conf.xml übernommen. Sie können
%1 und
%2 löschen
(eine Sicherheitskopie wäre nicht schlecht).</translation>
    </message>
    <message>
        <source>Step 3: Migrating ignored list to kadu.conf.xml</source>
        <translation>Schritt 2: Migration der Liste der zu ignorierenden Kontakte in kadu.conf.xml</translation>
    </message>
    <message>
        <source>Step 3: Ignored list migrated to kadu.conf.xml</source>
        <translation>Schritt 3: Liste der zu Ignorierenden in kadu.conf.xml übernommen</translation>
    </message>
    <message>
        <source>Ignored contact list migrated to kadu.conf.xml.
You can remove %1 now
(backup will be a good idea).</source>
        <translation>Liste der zu ignorierenden Kontakte in kadu.conf.xml übernommen.
Sie können %1 löschen
(eine Sicherheitskopie wäre nicht schlecht).</translation>
    </message>
    <message>
        <source>Step 4: Migrating config files to kadu.conf.xml</source>
        <translation>Schritt 4: Migratioen der Einstellungen in kadu.conf.xml</translation>
    </message>
    <message>
        <source>Step 4: Config files migrated to kadu.conf.xml</source>
        <translation>Schritt 4: Einstellungen in kadu.conf.xml übernommen</translation>
    </message>
    <message>
        <source>Configuration files migrated to kadu.conf.xml.
You can remove following files now:
%1
(backup will be a good idea).</source>
        <translation>Konfiguration wurde in kadu.conf.xml übernommen.
Sie können folgende Dateien löschen:
%1
(eine Sicherheitskopie wäre nicht schlecht).</translation>
    </message>
    <message>
        <source>Migration complete. Kadu will be closed now.
Please click Finish and than run Kadu again.</source>
        <translation>Migration beendet. Kadu wird geschlossen.
Klicken Sie auf &apos;Beenden&apos; und starten Sie Kadu erneut.</translation>
    </message>
    <message>
        <source>Migration complete.</source>
        <translation>Migration beendet.</translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.orig.tar.gz: kadu/modules/migration/translations/migration_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>MigrationDialog</name>
    <message>
        <location filename="../migration.cpp" line="38"/>
        <source>Migration</source>
        <translation>Migration</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="41"/>
        <source>Migration steps</source>
        <translation>Migrationsschritte</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="46"/>
        <source>Migration in progress ...</source>
        <translation>Migration läuft...</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="47"/>
        <source>&amp;Finish</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="108"/>
        <source>Kadu detected, that you were using EKG, GnuGadu or
older version of Kadu before. Would you like to try
to import your settings from %1?</source>
        <translation>Kadu hat entdeckt, dass Sie EKG, GnuGadu oder
eine ältere Version von Kadu verwendet haben. Soll ich versuchen,
die Einstellungen von %1 zu importieren?</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="131"/>
        <source>Step 1: Migrating settings to kadu directory</source>
        <translation>Schritt 1: Migration der Einstellungen in das Kadu-Verzeichnis</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="148"/>
        <source>Step 1: Settings migrated to kadu directory</source>
        <translation>Schritt 1: Einstellungen wurden in das Kadu-Verzeichnis übernommen</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="151"/>
        <source>Migration process completed. You can remove
%1directory
(backup will be a good idea) or leave it for other applications.</source>
        <translation>Migration beendet. Sie können das Verzeichnis
%1 löschen
(eine Sicherungskopie wäre nicht schlecht) 
bzw. zur weiteren Verwendung für andere Programme lassen.</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="159"/>
        <source>Error migrating data!</source>
        <translation>Fehler bei der Übernahme der Einstellungen!</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="165"/>
        <source>Cannot start migration process!</source>
        <translation>Kann den Migration nicht starten!</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="194"/>
        <source>Step 2: Migrating user list to kadu.conf.xml</source>
        <translation>Schritt 2: MIgration der Kontaktliste in kadu.conf.xml</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="200"/>
        <source>Step 2: User list migrated to kadu.conf.xml</source>
        <translation>Schritt 2: Kontaktliste ins kadu.conf.xml übernommen</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="203"/>
        <source>Contact list migrated to kadu.conf.xml.You can remove
%1 and
%2 now
(backup will be a good idea).</source>
        <translation>Kontaktliste in kadu.conf.xml übernommen. Sie können
%1 und
%2 löschen
(eine Sicherheitskopie wäre nicht schlecht).</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="231"/>
        <source>Step 3: Migrating ignored list to kadu.conf.xml</source>
        <translation>Schritt 2: Migration der Liste der zu ignorierenden Kontakte in kadu.conf.xml</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="266"/>
        <source>Step 3: Ignored list migrated to kadu.conf.xml</source>
        <translation>Schritt 3: Liste der zu Ignorierenden in kadu.conf.xml übernommen</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="269"/>
        <source>Ignored contact list migrated to kadu.conf.xml.
You can remove %1 now
(backup will be a good idea).</source>
        <translation>Liste der zu ignorierenden Kontakte in kadu.conf.xml übernommen.
Sie können %1 löschen
(eine Sicherheitskopie wäre nicht schlecht).</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="378"/>
        <source>Step 4: Migrating config files to kadu.conf.xml</source>
        <translation>Schritt 4: Migratioen der Einstellungen in kadu.conf.xml</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="399"/>
        <source>Step 4: Config files migrated to kadu.conf.xml</source>
        <translation>Schritt 4: Einstellungen in kadu.conf.xml übernommen</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="402"/>
        <source>Configuration files migrated to kadu.conf.xml.
You can remove following files now:
%1
(backup will be a good idea).</source>
        <translation>Konfiguration wurde in kadu.conf.xml übernommen.
Sie können folgende Dateien löschen:
%1
(eine Sicherheitskopie wäre nicht schlecht).</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="420"/>
        <source>Migration complete. Kadu will be closed now.
Please click Finish and than run Kadu again.</source>
        <translation>Migration beendet. Kadu wird geschlossen.
Klicken Sie auf &apos;Beenden&apos; und starten Sie Kadu erneut.</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="422"/>
        <source>Migration complete.</source>
        <translation>Migration beendet.</translation>
    </message>
</context>
</TS>
